@@ -19,6 +19,7 @@
 
 #include "process_attribute.h"
 #include "processes.h"
+#include "cgroup.h"
 
 using namespace KSysGuard;
 
@@ -162,3 +163,17 @@ void ProcessAttribute::clearData(KSysGuard::Process *process)
     d->m_data.remove(process);
     emit dataChanged(process);
 }
+
+QVariant ProcessAttribute::cgroupData(KSysGuard::CGroup *cgroup, const QVector<KSysGuard::Process*> &groupProcesses) const
+{
+    Q_UNUSED(cgroup)
+
+    if (groupProcesses.isEmpty()) {
+        return QVariant{};
+    }
+
+    qreal total = std::accumulate(groupProcesses.constBegin(), groupProcesses.constEnd(), 0.0, [this](qreal total, KSysGuard::Process *process) {
+        return total + data(process).toDouble();
+    });
+    return QVariant(total);
+}
